aboutsummaryrefslogtreecommitdiffstats
path: root/libsolidity/codegen/ABIFunctions.h
diff options
context:
space:
mode:
authorchriseth <chris@ethereum.org>2017-10-04 22:56:54 +0800
committerchriseth <chris@ethereum.org>2017-10-04 22:56:54 +0800
commit80cefb9cc810a96fea5817511d3fd908e960bf80 (patch)
treee554ebe330841a4bc96eb410d12d262cad0d8e88 /libsolidity/codegen/ABIFunctions.h
parentacd70557ccb6e86bcbfb14197f30a285d9992d6b (diff)
downloaddexon-solidity-80cefb9cc810a96fea5817511d3fd908e960bf80.tar.gz
dexon-solidity-80cefb9cc810a96fea5817511d3fd908e960bf80.tar.zst
dexon-solidity-80cefb9cc810a96fea5817511d3fd908e960bf80.zip
Rename "compacted" to "fromStack".
Diffstat (limited to 'libsolidity/codegen/ABIFunctions.h')
-rw-r--r--libsolidity/codegen/ABIFunctions.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/libsolidity/codegen/ABIFunctions.h b/libsolidity/codegen/ABIFunctions.h
index de2a140a..e61f68bc 100644
--- a/libsolidity/codegen/ABIFunctions.h
+++ b/libsolidity/codegen/ABIFunctions.h
@@ -89,13 +89,13 @@ private:
/// @returns the name of the ABI encoding function with the given type
/// and queues the generation of the function to the requested functions.
/// @param _compacted if true, the input value was just loaded from storage
/// or memory and thus might be compacted into a single slot (depending on the type).
std::string abiEncodingFunction(
Type const& _givenType,
Type const& _targetType,
bool _encodeAsLibraryTypes,
- bool _compacted
+ bool _fromStack
);
/// Part of @a abiEncodingFunction for array target type and given calldata array.
std::string abiEncodingFunctionCalldataArray(
@@ -143,7 +143,7 @@ private:
FunctionType const& _from,
Type const& _to,
bool _encodeAsLibraryTypes,
- bool _compacted
+ bool _fromStack
);
/// @returns a function that copies raw bytes of dynamic length from calldata
@@ -89,13 +89,13 @@ private:
/// @returns the name of the ABI encoding function with the given type
/// and queues the generation of the function to the requested functions.
- /// @param _compacted if true, the input value was just loaded from storage
+ /// @param _fromStack if false, the input value was just loaded from storage
/// or memory and thus might be compacted into a single slot (depending on the type).
std::string abiEncodingFunction(